from django.urls import path
from rest_framework_nested import routers
from .views import SchemaView, SampleBulkCreateView, SampleBulkDeleteView
from .viewsets import (CodeRuleViewSet, SampleViewSet,
                       SampleOperationViewSet, AreaViewSet, SubAreaViewSet, RefrigeratorViewSet,
                       FrozenFrameViewSet, FrozenBoxViewSet)

router = routers.SimpleRouter()
router.register(r'code-rules', CodeRuleViewSet)
router.register(r'samples', SampleViewSet)
router.register(r'sample-operations', SampleOperationViewSet)
router.register(r'areas', AreaViewSet)
router.register(r'refrigerators', RefrigeratorViewSet)
router.register(r'frozen-frames', FrozenFrameViewSet)
router.register(r'frozen-boxes', FrozenBoxViewSet)

area_router = routers.NestedSimpleRouter(router, r'areas', lookup='area')
area_router.register(r'subareas', SubAreaViewSet, basename='area-subareas')
area_router.register(r'refrigerators', RefrigeratorViewSet, basename='area-refrigerators')
refrigerator_router = routers.NestedSimpleRouter(router, r'refrigerators', lookup='refrigerator')
refrigerator_router.register(r'frozen-frames', FrozenFrameViewSet, basename='refrigerator-frozen_frames')
frozen_frame_router = routers.NestedSimpleRouter(router, r'frozen-frames', lookup='frozen_frame')
frozen_frame_router.register(r'frozen-boxes', FrozenBoxViewSet, basename='frozen_frame-frozen_boxes')

urlpatterns = router.urls
urlpatterns += area_router.urls
urlpatterns += refrigerator_router.urls
urlpatterns += frozen_frame_router.urls

urlpatterns += [
    path('schemas/', SchemaView.as_view(), name='schemas'),
    path('sample-bulk-create/', SampleBulkCreateView.as_view(), name='sample-bulk-create'),
    path('sample-bulk-delete/', SampleBulkDeleteView.as_view(), name='sample-bulk-delete'),
]
