import re
import datetime
import string
import random


def random_serial_number(size):
    char_lists = string.ascii_uppercase + string.digits
    return ''.join(random.choice(char_lists) for _ in range(size))


def get_placeholder_key(rule):
    segments = rule.segments
    seg_key = None
    for seg in segments:
        if seg['segment_type'] == 'placeholder':
            seg_key = seg['segment_key']

    return seg_key


def generate_code_by_rule(rule, placeholder=None):
    ordered_seg_items = str(rule.segment_order).split(',')
    segments = rule.segments
    lst = []
    if placeholder:
        placeholder = str(placeholder).upper()

    for item in ordered_seg_items:
        for seg in segments:
            if seg['segment_key'] == item:
                if seg['segment_type'] == 'constant':
                    lst.append(seg['segment_value'])
                elif seg['segment_type'] == 'date':
                    lst.append(datetime.datetime.now().strftime(seg['segment_type_date_display']))
                elif seg['segment_type'] == 'placeholder':
                    lst.append(placeholder)
                elif seg['segment_type'] == 'random':
                    lst.append(random_serial_number(seg['segment_type_random_size']))

    return ''.join(lst)


def get_real_code(code):
    pattern = '{(.*?)}'
    date_format = re.findall(pattern, code)[0]
    new_date_str = datetime.datetime.now().strftime(str(date_format))
    origin_str = '{' + date_format + '}'
    return str(code).replace(origin_str, new_date_str)