from rest_framework.generics import CreateAPIView
from rest_framework.views import APIView
from rest_framework.response import Response
from rest_framework.permissions import IsAuthenticated
from rest_framework import status

from side.schemas import get_model_schema

from .serializers import (SampleSerializer, SampleListSerializer, SampleBulkDestroySerializer,
                          SampleOperationSerializer, AreaSerializer, RefrigeratorSerializer,
                          FrozenFrameSerializer, FrozenBoxSerializer)
from .models import Sample, SampleOperation, Area, Refrigerator, FrozenFrame, FrozenBox


class SchemaView(APIView):
    permission_classes = [IsAuthenticated]

    def get(self, request, format=None):
        exclude_list = ['id', 'project_id', 'created_at', 'updated_at']
        sample = get_model_schema(model_class=Sample,
                                  serializer_class=SampleSerializer,
                                  exclude_fields=exclude_list)
        sample_operation = get_model_schema(model_class=SampleOperation,
                                            serializer_class=SampleOperationSerializer,
                                            exclude_fields=exclude_list)
        area = get_model_schema(model_class=Area,
                                serializer_class=AreaSerializer,
                                exclude_fields=exclude_list)
        refrigerator = get_model_schema(model_class=Refrigerator,
                                        serializer_class=RefrigeratorSerializer,
                                        exclude_fields=exclude_list)
        frozen_frame = get_model_schema(model_class=FrozenFrame,
                                        serializer_class=FrozenFrameSerializer,
                                        exclude_fields=exclude_list)
        frozen_box = get_model_schema(model_class=FrozenBox,
                                      serializer_class=FrozenBoxSerializer,
                                      exclude_fields=exclude_list)
        data = {}
        data.update({'sample': sample,
                     'sample_operation': sample_operation,
                     'area':area,
                     'refrigerator': refrigerator,
                     'frozen_frame':frozen_frame,
                     'frozen_box': frozen_box})
        return Response({"status_code": 200,
                         "data": data})


class SampleBulkCreateView(CreateAPIView):
    permission_classes = [IsAuthenticated]
    serializer_class = SampleListSerializer


class SampleBulkDeleteView(CreateAPIView):
    permission_classes = [IsAuthenticated]
    serializer_class = SampleBulkDestroySerializer

    @staticmethod
    def delete_sample(sample_id):
        sample = Sample.objects.get_by_natural_key(sample_id)
        if sample:
            sample.delete()

    def post(self, request, *args, **kwargs):
        sample_ids = request.data['sample_ids']
        map(self.delete_sample, sample_ids)
        return Response(status=status.HTTP_204_NO_CONTENT)



