from rest_framework.permissions import IsAuthenticated
from rest_framework import status
from rest_framework.response import Response
from side.viewsets import ModelViewSet

from .models import (CodeRule, Sample, SampleOperation, Area,
                     Refrigerator, FrozenFrame, FrozenBox)
from .serializers import (CodeRuleSerializer, SampleSerializer, SampleOperationSerializer,
                          AreaSerializer,SubareaSerializer,
                          RefrigeratorSerializer, FrozenFrameSerializer, FrozenBoxSerializer)


class CodeRuleViewSet(ModelViewSet):
    queryset = CodeRule.objects.all()
    serializer_class = CodeRuleSerializer
    permission_classes = [IsAuthenticated]
    filterset_fields = ['tag', ]
    search_fields = ['tag', ]
    ordering_fields = ['tag', ]


class SampleViewSet(ModelViewSet):
    queryset = Sample.objects.all()
    serializer_class = SampleSerializer
    permission_classes = [IsAuthenticated]


class SampleOperationViewSet(ModelViewSet):
    queryset = SampleOperation.objects.all()
    serializer_class = SampleOperationSerializer
    permission_classes = [IsAuthenticated]


class AreaViewSet(ModelViewSet):
    queryset = Area.objects.all()
    serializer_class = AreaSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'


class SubAreaViewSet(ModelViewSet):
    queryset = Area.objects.all()
    serializer_class = SubareaSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'

    def list(self, request, *args, **kwargs):
        queryset = self.filter_queryset(self.get_queryset().
                                        filter(parent_id=kwargs.get('area_id')))
        page = self.paginate_queryset(queryset)
        if page is not None:
            serializer = self.get_serializer(page, many=True)
            return self.get_paginated_response(serializer.data)

        serializer = self.get_serializer(queryset, many=True)
        return Response({"status_code": Response.status_text,
                         "data": serializer.data})

    def create(self, request, *args, **kwargs):
        data = request.data
        data['area_id'] = kwargs.get('area_id')
        serializer = self.get_serializer(data=data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)
        headers = self.get_success_headers(serializer.data)
        return_data = {"status_code": status.HTTP_201_CREATED,
                       "data": serializer.data}
        return Response(return_data, status=status.HTTP_201_CREATED, headers=headers)


class RefrigeratorViewSet(ModelViewSet):
    queryset = Refrigerator.objects.all()
    serializer_class = RefrigeratorSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'

    def create(self, request, *args, **kwargs):
        data = request.data
        if kwargs.__contains__('area_id'):
            area_id = kwargs.pop('area_id')
            data['area_id'] = area_id
        serializer = self.get_serializer(data=data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)
        headers = self.get_success_headers(serializer.data)
        return_data = {"status_code": status.HTTP_201_CREATED,
                       "data": serializer.data}
        return Response(return_data, status=status.HTTP_201_CREATED, headers=headers)


class FrozenFrameViewSet(ModelViewSet):
    queryset = FrozenFrame.objects.all()
    serializer_class = FrozenFrameSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'

    def create(self, request, *args, **kwargs):
        data = request.data
        if kwargs.__contains__('refrigerator_id'):
            refrigerator_id = kwargs.pop('refrigerator_id')
            data['refrigerator_id'] = refrigerator_id
        serializer = self.get_serializer(data=data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)
        headers = self.get_success_headers(serializer.data)
        return_data = {"status_code": status.HTTP_201_CREATED,
                       "data": serializer.data}
        return Response(return_data, status=status.HTTP_201_CREATED, headers=headers)


class FrozenBoxViewSet(ModelViewSet):
    queryset = FrozenBox.objects.all()
    serializer_class = FrozenBoxSerializer
    permission_classes = [IsAuthenticated]

    def create(self, request, *args, **kwargs):
        data = request.data
        if kwargs.__contains__('frozen_frame_id'):
            frozen_frame_id = kwargs.pop('frozen_frame_id')
            data['frozen_frame_id'] = frozen_frame_id
        serializer = self.get_serializer(data=data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)
        headers = self.get_success_headers(serializer.data)
        return_data = {"status_code": status.HTTP_201_CREATED,
                       "data": serializer.data}
        return Response(return_data, status=status.HTTP_201_CREATED, headers=headers)