from drf_yasg.utils import swagger_auto_schema

from rest_framework import viewsets
from rest_framework.permissions import IsAuthenticated
from rest_framework.decorators import action
from rest_framework.generics import GenericAPIView
from rest_framework.response import Response
from rest_framework.exceptions import APIException

from side.monitoring.mixins import APIRequestMixin
from . import utils
from .serializers import ACSSerializer, AliyunNLPSerializer


class ProxyServiceViewSets(viewsets.ViewSet, APIRequestMixin, GenericAPIView):
    permission_classes = [IsAuthenticated]

    @swagger_auto_schema(methods=['POST'],
                         request_body=ACSSerializer)
    @action(detail=False, methods=['POST'], name='Hikvision ACS Proxy Service')
    def acs(self, request):
        url = request.data.get('url', None)
        uri = request.data.get('uri', None)
        xcakey = request.data.get('xcakey', None)
        payload = request.data.get('payload', None)
        try:
            result = utils.acs(url=url, uri=uri, xcakey=xcakey, payload=payload)
            return Response({"status_code": 200,
                             "data": result})
        except Exception:
            raise APIException(detail='Fail to register ACS, please check the params.')
    
    @swagger_auto_schema(methods=['POST'], request_body=AliyunNLPSerializer)
    @action(detail=False, methods=['POST'], name='Aliyun NLP Proxy Service')
    def aliyun_nlp(self, request):
        access_key_id = request.data.get('access_key_id', None)
        access_key_secret = request.data.get('access_key_secret', None)
        endpoint = request.data.get('endpoint', None)
        api_version = request.data.get('api_version', None)
        region_id = request.data.get('region_id', None)
        model_id = request.data.get('model_id', None)
        model_version = request.data.get('model_version', None)
        content = request.data.get('content', None)
        try:
            result = utils.aliyun_nlp(access_key_id=access_key_id,
                                      access_key_secret=access_key_secret,
                                      endpoint=endpoint,
                                      api_version=api_version,
                                      region_id=region_id,
                                      model_id=model_id,
                                      model_version=model_version,
                                      content=content)
            return Response({"status_code": 200,
                             "data": result})
        except Exception:
            raise APIException(detail='Fail to call Aliyun NLP service, please check the params.')


