"""
This file was generated with the dashboard management command and
contains the class for the main dashboard.

To activate your index dashboard add the following to your settings.py::
    GRAPPELLI_INDEX_DASHBOARD = 'side.dashboard.IndexDashboard'
"""

from django.utils.translation import gettext_lazy as _

from grappelli.dashboard import modules, Dashboard
from grappelli.dashboard.utils import get_admin_site_name


class IndexDashboard(Dashboard):
    """
    Index dashboard for www.
    """

    def init_with_context(self, context):
        site_name = get_admin_site_name(context)

        # Identity & Security
        self.children.append(modules.Group(
            title="Identity & Access Control",
            column=1,
            collapsible=True,
            children=[
                modules.ModelList(
                    title='Identity Management',
                    models=('side.identity.*',)
                ),
                modules.ModelList(
                    title='Tokens',
                    models=('rest_framework_simplejwt.token_blacklist.models.*',)
                )
            ]
        ))

        # Tracing & Monitoring
        self.children.append(modules.Group(
            title="Tracing & Monitoring",
            column=2,
            collapsible=True,
            children=[
                modules.ModelList(
                    title='API Request Tracing',
                    models=('side.monitoring.models.*',)
                ),
            ]
        ))

        # append a recent actions module
        self.children.append(modules.RecentActions(
            _('Recent actions'),
            limit=5,
            collapsible=False,
            column=3,
        ))

        self.children.append(modules.LinkList(
            title='Links',
            column=3,
            children=(
                ['OpenAPI Swagger', 'http://side.fineartit.com/docs/swagger/', True],
                ['OpenAPI ReDoc', 'http://side.fineart.com/docs/redoc/', True],
            )
        ))