"""Provide exceptions to be raised by the `dynamic_models` app.

All exceptions inherit from a `ModelSchemaError` base class.
"""


class ModelSchemaError(Exception):
    """Base exception for use in dynamic models."""


class OutdatedModelSchemaError(ModelSchemaError):
    """Raised when a model's schema is outdated on save."""


class NullFieldChangedError(ModelSchemaError):
    """Raised when a field is attempted to be change from NULL to NOT NULL."""


class InvalidFieldNameError(ModelSchemaError):
    """Raised when a field name is invalid."""


class UnsavedSchemaError(ModelSchemaError):
    """
    Raised when a model schema has not been saved to the db and a dynamic model
    is attempted to be created.
    """
