from django.urls import path
from rest_framework_nested import routers

from .views import TagBulkCreateView, TagBulkDeleteView
from .viewsets import (TagViewSet, FormViewSet, VocabViewSet, VocabEntryViewSet,
                       ConfigViewSet, ExtraViewSet)

router = routers.SimpleRouter()
router.register(r'tags', TagViewSet)
router.register(r'forms', FormViewSet)
router.register(r'configs', ConfigViewSet)
router.register(r'extras', ExtraViewSet)
router.register(r'vocabs', VocabViewSet)
vocab_router = routers.NestedSimpleRouter(router, r'vocabs', lookup='vocab')
vocab_router.register(r'entries', VocabEntryViewSet, basename='vocab-entries')
urlpatterns = router.urls
urlpatterns += vocab_router.urls

urlpatterns += [
    path('tag-bulk-create/', TagBulkCreateView.as_view(), name='tag-bulk-create'),
    path('tag-bulk-delete/', TagBulkDeleteView.as_view(), name='tag-bulk-delete'),
]
