from rest_framework.permissions import IsAuthenticated
from rest_framework import status
from rest_framework.response import Response

from side.viewsets import ModelViewSet, ListModelViewSet
from side.data.models import Tag, Form, Vocab, VocabEntry, Config, Extra
from side.data.serializers import (TagSerializer, FormSerializer, VocabSerializer,
                                   VocabEntrySerializer, ConfigSerializer, ExtraSerializer)


class TagViewSet(ModelViewSet):
    queryset = Tag.objects.all()
    serializer_class = TagSerializer
    permission_classes = [IsAuthenticated]
    filterset_fields = ['key', 'label']
    search_fields = ['key', 'label']
    ordering_fields = ['key', 'label']


class FormViewSet(ModelViewSet):
    queryset = Form.objects.all()
    serializer_class = FormSerializer
    permission_classes = [IsAuthenticated]
    filterset_fields = ['title',]
    search_fields = ['title', ]
    ordering_fields = ['title',]


class VocabViewSet(ModelViewSet):
    queryset = Vocab.objects.all()
    serializer_class = VocabSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'
    filterset_fields = ['name',]
    search_fields = ['name',]
    ordering_fields = ['name',]


class VocabEntryViewSet(ModelViewSet):
    queryset = VocabEntry.objects.all()
    serializer_class = VocabEntrySerializer
    permission_classes = [IsAuthenticated]
    filterset_fields = ['entry_label', ]
    search_fields = ['entry_label', ]
    ordering_fields = ['entry_label', ]

    def create(self, request, *args, **kwargs):
        vocab_id = kwargs.pop('vocab_id')
        data = request.data
        data['vocab_id'] = vocab_id
        serializer = self.get_serializer(data=data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)
        headers = self.get_success_headers(serializer.data)
        return_data = {"status_code": status.HTTP_201_CREATED,
                       "data": serializer.data}
        return Response(return_data, status=status.HTTP_201_CREATED, headers=headers)


class ConfigViewSet(ModelViewSet):
    queryset = Config.objects.all()
    serializer_class = ConfigSerializer
    permission_classes = [IsAuthenticated]


class ExtraViewSet(ModelViewSet):
    queryset = Extra.objects.all()
    serializer_class = ExtraSerializer
    permission_classes = [IsAuthenticated]