from django.core.exceptions import PermissionDenied
from django.db import connection, transaction
from django.http import Http404

from rest_framework import exceptions
from rest_framework.response import Response


def set_rollback():
    atomic_requests = connection.settings_dict.get('ATOMIC_REQUESTS', False)
    if atomic_requests and connection.in_atomic_block:
        transaction.set_rollback(True)


def exception_handler(exc, context):
    if isinstance(exc, Http404):
        exc = exceptions.NotFound()
    elif isinstance(exc, PermissionDenied):
        exc = exceptions.PermissionDenied()

    if isinstance(exc, exceptions.APIException):
        headers = {}
        if getattr(exc, 'auth_header', None):
            headers['WWW-Authenticate'] = exc.auth_header
        if getattr(exc, 'wait', None):
            headers['Retry-After'] = '%d' % exc.wait
        detail = exc.detail
        if isinstance(detail, dict) and detail.get('errors', False):
            message = exc.detail['errors'][0]
        else:
            message = detail
        data = {'status_code': exc.status_code, 'message': message}
        set_rollback()
        return Response(data, status=exc.status_code, headers=headers)

    return None