from django.contrib import admin
from django.contrib.auth.admin import UserAdmin as DefaultUserAdmin
from django.contrib.auth.admin import GroupAdmin
from django.contrib.auth.models import Group
from django.utils.text import gettext_lazy as _

from side.identity.models import Project, User, Role

admin.site.unregister(Group)
admin.site.register(Role, GroupAdmin)


@admin.register(Project)
class ProjectAdmin(admin.ModelAdmin):
    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('name', 'description', 'is_active'),
        }),
    )
    list_display = ('id', 'name', 'is_active', 'description')
    readonly_fields = ['id', 'created_at', 'updated_at']
    exclude = ('deleted_at', 'extras')


@admin.register(User)
class UserAdmin(DefaultUserAdmin):

    fieldsets = (
        (None, {'fields': ('default_project_id', 'username', 'password')}),
        (_('Personal info'), {'fields': ('first_name', 'last_name', 'email', 'mobile')}),
        (_('Permissions'), {'fields': ('is_active', 'is_staff',
                                       'is_superuser', 'groups')}),
        (_('Important dates'), {'fields': ('last_login', 'date_joined', 'updated_at')}),
    )
    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('username', 'email', 'mobile', 'password1',
                       'password2'),
        }),
    )
    list_display = ('username', 'default_project_id', 'email',
                    'first_name', 'last_name', 'mobile', 'is_staff')
    list_filter = ('is_staff', 'is_superuser', 'is_active', 'groups')
    search_fields = ('username', 'first_name', 'last_name', 'email', 'mobile')
    readonly_fields = ('date_joined', 'last_login', 'updated_at')
    filter_horizontal = ('groups', 'user_permissions',)
    exclude = ('deleted_at', 'extras')
