from django.apps import apps
from django.contrib.auth.base_user import BaseUserManager
from django.db import models


class UserManager(BaseUserManager):
    use_in_migrations = True

    def _create_user(self, username, email, password, **extra_fields):
        """
        Create and save a user with the given username, email, and password.
        """
        if not username:
            raise ValueError('The given username must be set')
        email = self.normalize_email(email)
        username = self.model.normalize_username(username)
        user = self.model(username=username, email=email, **extra_fields)
        user.set_password(password)
        user.save(using=self._db)
        return user

    def _create_superuser(self, username, email, password, **extra_fields):
        """
        Create and save a superuser with the given username, email, and password.
        """
        if not username:
            raise ValueError('The given username must be set')
        email = self.normalize_email(email)
        username = self.model.normalize_username(username)
        Project = apps.get_model('identity', 'Project')
        project = Project.objects.get(name='side')
        user = self.model(username=username, default_project_id=project.id, email=email, **extra_fields)
        user.set_password(password)
        Role = apps.get_model('identity', 'Role')
        role = Role.objects.get(name='admin')
        user.save(using=self._db)
        user.groups.add(role)
        user.user_permissions.set(role.permissions.all())
        return user

    def create_user(self, username, email=None, password=None, **extra_fields):
        extra_fields.setdefault('is_staff', False)
        extra_fields.setdefault('is_superuser', False)
        return self._create_user(username, email, password, **extra_fields)

    def create_superuser(self, username, email=None, password=None, **extra_fields):
        extra_fields.setdefault('is_staff', True)
        extra_fields.setdefault('is_superuser', True)

        if extra_fields.get('is_staff') is not True:
            raise ValueError('Superuser must have is_staff=True.')
        if extra_fields.get('is_superuser') is not True:
            raise ValueError('Superuser must have is_superuser=True.')

        return self._create_superuser(username, email, password, **extra_fields)


class RoleManager(models.Manager):
    """
    The manager for the identity Role model.
    """
    use_in_migrations = True

    def get_by_natural_key(self, pk):
        return self.get(pk=pk)


class ProjectManager(models.Manager):
    """
    The manager for the identity Project model.
    """
    use_in_migrations = True

    def get_by_natural_key(self, pk):
        return self.get(pk=pk)


