from django.contrib.auth import get_user_model
from django.contrib.auth.models import Permission

from rest_framework.exceptions import APIException
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from rest_framework import status

from side.viewsets import ModelViewSet, ReadOnlyModelViewSet
from side.identity.models import Project, Role
from side.identity.serializers import UserSerializer, PermissionSerializer, ProjectSerializer

User = get_user_model()


class UserViewSet(ModelViewSet):
    queryset = User.objects.all()
    serializer_class = UserSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'
    filterset_fields = ['default_project_id', 'username', 'email', 'mobile', 'is_active', 'is_staff']
    search_fields = ['default_project_id', 'username', 'email', 'mobile', 'is_active', 'is_staff']
    ordering_fields = ['default_project_id', 'username', 'email', 'mobile', 'is_active', 'is_staff']


class PermissionReadOnlyViewSet(ReadOnlyModelViewSet):
    queryset = Permission.objects.all()
    serializer_class = PermissionSerializer
    permission_classes = [IsAuthenticated]

    def list(self, request, *args, **kwargs):
        queryset = self.filter_queryset(self.get_queryset())
        page = self.paginate_queryset(queryset)
        if page is not None:
            serializer = self.get_serializer(page, many=True)
            return self.get_paginated_response(serializer.data)

        serializer = self.get_serializer(queryset, many=True)
        return Response({"status_code": Response.status_text,
                         "data": serializer.data})


class ProjectViewSet(ModelViewSet):
    queryset = Project.objects.all()
    serializer_class = ProjectSerializer
    permission_classes = [IsAuthenticated]
    lookup_field = 'id'
    filterset_fields = ['name', ]
    search_fields = ['name', ]
    ordering_fields = ['name', ]
