from django.contrib import admin
from .models import APIRequest


class APIRequestAdmin(admin.ModelAdmin):
    date_hierarchy = 'requested_at'
    list_display = ('id', 'project_name', 'requested_at', 'response_ms', 'status_code',
                    'user', 'view_method', 'path', 'remote_addr', 'host', 'query_params')
    list_filter = ('project_name', 'view_method', 'status_code')
    search_fields = ('path', 'user__email',)
    raw_id_fields = ('user', )
    readonly_fields = ('id', 'project_name', 'user', 'username_persistent', 'requested_at',
                       'response_ms', 'path', 'view', 'view_method', 'remote_addr', 'host',
                       'method', 'query_params', 'data', 'response', 'errors', 'status_code')
    ordering = ('-requested_at',)

    def get_queryset(self, request):
        qs = super(APIRequestAdmin, self).get_queryset(request)
        return qs.filter(project_id=request.user.default_project_id)

    def has_add_permission(self, request):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_delete_permission(self, request, obj=None):
        return False


admin.site.register(APIRequest, APIRequestAdmin)

