import re
from .patterns import MOBILE_PHONE_NUMBER_PATTERN, ID_CARD_NUMBER_PATTERN


class RegexMatcher:

    @staticmethod
    def _match(pattern, text, label, offset=True):
        if offset:
            results = [{'text': item.group(1),
                        'label': label,
                        'start': item.span()[0] - 1,
                        'end': item.span()[1] - 1}
                       for item in pattern.finditer(text)]
        else:
            results = [{'text': item.group(1),
                        'label': label}
                       for item in pattern.finditer(text)]

        return results

    @classmethod
    def match_chinese_mobile_phone_number(cls, text, offset=True):
        pattern = re.compile(MOBILE_PHONE_NUMBER_PATTERN)
        text = ''.join(['#', text, '#'])
        return cls._match(pattern, text, label='MOBILE-PHONE-NUMBER', offset=offset)

    @classmethod
    def match_chinese_id_card_number(cls, text, offset=True):
        pattern = re.compile(ID_CARD_NUMBER_PATTERN)
        text = ''.join(['#', text, '#'])
        return cls._match(pattern, text, label='ID-CARD-NUMBER', offset=offset)


