"""side URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.conf import settings
from django.urls import path, re_path, include
from django.views import static
from rest_framework.permissions import AllowAny
from drf_yasg.views import get_schema_view
from drf_yasg import openapi

# from side.data.urls import router as data_router
from side.identity.urls import router as identity_router
from side.nlp.urls import router as nlp_router
from .views import index as index_view

schema_view = get_schema_view(
   openapi.Info(
      title="SIDE NLP DOCS",
      default_version='v1.0',
   ),
   public=True,
   permission_classes=(AllowAny,),
)


urlpatterns = [
    path('', index_view, name='index'),
    path('docs/swagger<str:format>', schema_view.without_ui(cache_timeout=0), name='schema-json'),
    path('docs/swagger/', schema_view.with_ui('swagger', cache_timeout=0), name='schema-swagger-ui'),
    path('docs/redoc/', schema_view.with_ui('redoc', cache_timeout=0), name='schema-redoc'),
    path('grappelli/', include('grappelli.urls')),
    path('admin/', admin.site.urls),
    # path('data/', include(data_router.urls)),
    path('identity/', include(identity_router.urls)),
    path('nlp/', include(nlp_router.urls)),
]

urlpatterns += [
    re_path(r'^static/(?P<path>.*)$', static.serve,
            {'document_root': settings.STATIC_ROOT}),
]


# Enable extra urls
if getattr(settings, 'enable_proxy', False):
    from side.biz.bot.urls import router as proxy_router
    urlpatterns += [
        path('proxy/', include(proxy_router.urls)),
    ]
if getattr(settings, 'enable_bio', False):
    from side.biz.bio.urls import router as bio_router
    urlpatterns += [
        path('bio/', include(bio_router.urls)),
    ]