from pypinyin import lazy_pinyin
from fuzzywuzzy import fuzz


class FuzzyMatcher:

    @staticmethod
    def one_match_many(source, targets, lang='zh', threshold=0.5,
                       mode='simple', return_all=False):
        result = None
        lst = []
        score = None
        if lang == 'zh':
            source_pinyin = ' '.join(lazy_pinyin(source))
            for t in targets:
                if mode == 'simple':
                    score = fuzz.ratio(source_pinyin, ' '.join(lazy_pinyin(t))) / 100
                if mode == 'partial':
                    score = fuzz.partial_ratio(source_pinyin, ' '.join(lazy_pinyin(t))) / 100
                if mode == 'token_sort':
                    score = fuzz.token_sort_ratio(source_pinyin, ' '.join(lazy_pinyin(t))) / 100
                if mode == 'token_set':
                    score = fuzz.token_set_ratio(source_pinyin, ' '.join(lazy_pinyin(t))) / 100
                if score >= threshold:
                    lst.append({'source': source, 'target': t, 'score': score})
        else:
            for c in targets:
                if mode == 'simple':
                    score = fuzz.ratio(source, c) / 100
                if mode == 'partial':
                    score = fuzz.partial_ratio(source, c) / 100
                if mode == 'token_sort':
                    score = fuzz.token_sort_ratio(source, c) / 100
                if mode == 'token_set':
                    score = fuzz.token_set_ratio(source, c) / 100
                if score >= threshold:
                    lst.append({'source': source, 'target': c, 'score': score})
        if lst:
            result = sorted(lst, key=lambda t: t['score'], reverse=True)

        if not return_all:
            result = result[0]

        return result

    @staticmethod
    def many_match_one(sources, target, lang='zh', threshold=0.5,
                       mode='simple', return_all=False):
        result = None
        lst = []
        score = None
        if lang == 'zh':
            target_pinyin = ' '.join(lazy_pinyin(target))
            for s in sources:
                if mode == 'simple':
                    score = fuzz.ratio(target_pinyin, ' '.join(lazy_pinyin(s))) / 100
                if mode == 'partial':
                    score = fuzz.partial_ratio(target_pinyin, ' '.join(lazy_pinyin(s))) / 100
                if mode == 'token_sort':
                    score = fuzz.token_sort_ratio(target_pinyin, ' '.join(lazy_pinyin(s))) / 100
                if mode == 'token_set':
                    score = fuzz.token_set_ratio(target_pinyin, ' '.join(lazy_pinyin(s))) / 100
                if score >= threshold:
                    lst.append({'source': s, 'target': target, 'score': score})
        else:
            for s in sources:
                if mode == 'simple':
                    score = fuzz.ratio(target, s) / 100
                if mode == 'partial':
                    score = fuzz.partial_ratio(target, s) / 100
                if mode == 'token_sort':
                    score = fuzz.token_sort_ratio(target, s) / 100
                if mode == 'token_set':
                    score = fuzz.token_set_ratio(target, s) / 100
                if score >= threshold:
                    lst.append({'source': s, 'target': target, 'score': score})
        if lst:
            result = sorted(lst, key=lambda t: t['score'], reverse=True)

        if not return_all:
            result = result[0]

        return result
